@@ -91,11 +91,6 @@ class hack:
                     		
                         except:
                     	    break
-    def cmd():
-        import os
-        a = input('       ')
-        if a == "start":
-            os.startfile('cmd')
     def port():
         import os
         if a == "port":
@@ -205,101 +200,114 @@ class hack:
              threading.Thread(target=website).start()
 class cmd():
     def command():
-        print('ASSOC          Вывод либо изменение сопоставлений по расширениям имен файлов.')
-        print('ATTRIB         Отображение и изменение атрибутов файлов.')
-        print('BREAK        Включение и выключение режима обработки комбинации клавиш CTRL+C.')
-        print('BCDEDIT        Задает свойства в базе данных загрузки для управления начальной')
-        print('               загрузкой.')
-        print('CACLS          Отображение и редактирование списков управления доступом (ACL)')
-        print('               к файлам.')
-        print('CALL           Вызов одного пакетного файла из другого.')
-        print('CD             Вывод имени либо смена текущей папки.')
-        print('CHCP           Вывод либо установка активной кодовой страницы.')
-        print('CHDIR          Вывод имени либо смена текущей папки.')
-        print('CHKDSK         Проверка диска и вывод статистики.')
-        print('CHKNTFS        Отображение или изменение выполнения проверки диска во время')
-        print('               загрузки.')
-        print('CLS            Очистка экрана.')
-        print('CMD            Запуск еще одного интерпретатора командных строк Windows.')
-        print('COLOR       Установка цветов переднего плана и фона, используемых по умолчанию.')
-        print('COMP           Сравнение содержимого двух файлов или двух наборов файлов.')
-        print('COMPACT        Отображение и изменение сжатия файлов в разделах NTFS.')
-        print('CONVERT        Преобразует тома FAT в NTFS. Вы не можете')
-        print('               преобразовать текущий диск.')
-        print('COPY           Копирование одного или нескольких файлов в другое место.')
-        print('DATE           Вывод либо установка текущей даты.')
-        print('DEL            Удаление одного или нескольких файлов.')
-        print('DIR            Вывод списка файлов и подпапок из указанной папки.')
-        print('DISKPART       Отображает или настраивает свойства раздела диска.')
-        print('DOSKEY         Редактирует командные строки, повторно вызывает команды Windows и создает')
-        print('               макросы.')
-        print('DRIVERQUERY    Отображает текущее состояние и свойства драйвера устройства.')
-        print('ECHO           Отображает сообщения и переключает режим отображения команд на экране.')
-        print('ENDLOCAL       Завершает локализацию изменений среды для пакетного файла.')
-        print('ERASE          Удаляет один или несколько файлов.')
-        print('EXIT           Завершает работу программы CMD.EXE (интерпретатора командных строк).')
-        print('FC             Сравнивает два файла или два набора файлов и')
-        print('               отображает различия между ними.')
-        print('FIND           Ищет текстовую строку в одном или нескольких файлах.')
-        print('FINDSTR        Ищет строки в файлах.')
-        print('FOR            Запускает указанную команду для каждого из файлов в наборе.')
-        print('FORMAT         Форматирует диск для работы с Windows.')
-        print('FSUTIL         Отображает или настраивает свойства файловой системы.')
-        print('FTYPE          Отображает либо изменяет типы файлов, используемые при')
-        print('               сопоставлении по расширениям имен файлов.')
-        print('GOTO           Направляет интерпретатор команд Windows в отмеченную строку')
-        print('               пакетной программы.')
-        print('GPRESULT       Отображает информацию о групповой политике для компьютера или пользователя.')
-        print('GRAFTABL       Позволяет Windows отображать расширенный набор символов в')
-        print('               графическом режиме.')
-        print('HELP           Выводит справочную информацию о командах Windows.')
-        print('ICACLS         Отображает, изменяет, архивирует или восстанавливает')
-        print('               списки ACL для файлов и каталогов.')
-        print('IF             Выполняет условную обработку в пакетных программах.')
-        print('LABEL          Создает, изменяет или удаляет метки тома для дисков.')
-        print('MD             Создает каталог.')
-        print('MKDIR          Создает каталог.')
-        print('MKLINK         Создает символьные ссылки и жесткие связи')
-        print('MODE           Настраивает системные устройства.')
-        print('MORE           Последовательно отображает данные по частям размером в один экран.')
-        print('MOVE           Перемещает один или несколько файлов из одного каталога')
-        print('               в другой.')
-        print('OPENFILES      Отображает файлы, открытые для файлового ресурса удаленными пользователями.')
-        print('PATH           Отображает или устанавливает путь поиска исполняемых файлов.')
-        print('PAUSE          Приостанавливает выполнение пакетного файла и выводит сообщение.')
-        print('POPD           Восстанавливает предыдущее значение текущего каталога,')
-        print('               сохраненное с помощью команды PUSHD.')
-        print('PRINT          Выводит на печать содержимое текстового файла.')
-        print('PROMPT         Изменяет командную строку Windows.')
-        print('PUSHD          Сохраняет текущий каталог, затем изменяет его.')
-        print('RD             Удаляет каталог.')
-        print('RECOVER        Восстанавливает данные, которые можно прочитать, с плохого или поврежденного диска.')
-        print('REM            Записывает комментарии в пакетные файлы или файл CONFIG.SYS.')
-        print('REN            Переименовывает файлы.')
-        print('RENAME         Переименовывает файлы.')
-        print('REPLACE        Заменяет файлы.')
-        print('RMDIR          Удаляет каталог.')
-        print('ROBOCOPY       Улучшенная служебная программа копирования файлов и деревьев папок')
-        print('SET            Показывает, устанавливает или удаляет переменные среды Windows.')
-        print('SETLOCAL       Начинает локализацию изменений среды в пакетном файле.')
-        print('SC             Отображает или настраивает службы (фоновые процессы).')
-        print('SCHTASKS       Выполняет команды и запускает программы на компьютере по расписанию.')
-        print('SHIFT          Изменяет положение заменяемых параметров в пакетных файлах.')
-        print('SHUTDOWN       Позволяет локально или удаленно завершить работу компьютера.')
-        print('SORT           Сортирует ввод.')
-        print('START          Выполняет указанную программу или команду в отдельном окне.')
-        print('SUBST          Связывает путь с именем диска.')
-        print('SYSTEMINFO     Отображает сведения о свойствах и конфигурации определенного компьютера.')
-        print('TASKLIST       Отображает все выполняемые задачи, включая службы.')
-        print('TASKKILL       Прекращение или остановка процесса либо приложения.')
-        print('TIME           Отображает или устанавливает системное время.')
-        print('TITLE          Назначает заголовок окна для сеанса CMD.EXE.')
-        print('TREE           Графически отображает структуру каталогов диска или')
-        print('          пути.')
-        print('TYPE           Отображает содержимое текстовых файлов.')
-        print('VER            Отображает сведения о версии Windows.')
-        print('VERIFY         Устанавливает режим проверки в Windows правильности записи')
-        print('               файлов на диск.')
-        print('VOL            Отображает метку и серийный номер тома для диска.')
-        print('XCOPY          Копирует файлы и деревья папок.')
-        print('WMIC           Отображает сведения об инструментарии WMI в интерактивной командной оболочке.')
+        a = input('       ')
+        if a == 'start':
+            print('ASSOC          Вывод либо изменение сопоставлений по расширениям имен файлов.')
+            print('ATTRIB         Отображение и изменение атрибутов файлов.')
+            print('BREAK        Включение и выключение режима обработки комбинации клавиш CTRL+C.')
+            print('BCDEDIT        Задает свойства в базе данных загрузки для управления начальной')
+            print('               загрузкой.')
+            print('CACLS          Отображение и редактирование списков управления доступом (ACL)')
+            print('               к файлам.')
+            print('CALL           Вызов одного пакетного файла из другого.')
+            print('CD             Вывод имени либо смена текущей папки.')
+            print('CHCP           Вывод либо установка активной кодовой страницы.')
+            print('CHDIR          Вывод имени либо смена текущей папки.')
+            print('CHKDSK         Проверка диска и вывод статистики.')
+            print('CHKNTFS        Отображение или изменение выполнения проверки диска во время')
+            print('               загрузки.')
+            print('CLS            Очистка экрана.')
+            print('CMD            Запуск еще одного интерпретатора командных строк Windows.')
+            print('COLOR       Установка цветов переднего плана и фона, используемых по умолчанию.')
+            print('COMP           Сравнение содержимого двух файлов или двух наборов файлов.')
+            print('COMPACT        Отображение и изменение сжатия файлов в разделах NTFS.')
+            print('CONVERT        Преобразует тома FAT в NTFS. Вы не можете')
+            print('               преобразовать текущий диск.')
+            print('COPY           Копирование одного или нескольких файлов в другое место.')
+            print('DATE           Вывод либо установка текущей даты.')
+            print('DEL            Удаление одного или нескольких файлов.')
+            print('DIR            Вывод списка файлов и подпапок из указанной папки.')
+            print('DISKPART       Отображает или настраивает свойства раздела диска.')
+            print('DOSKEY         Редактирует командные строки, повторно вызывает команды Windows и создает')
+            print('               макросы.')
+            print('DRIVERQUERY    Отображает текущее состояние и свойства драйвера устройства.')
+            print('ECHO           Отображает сообщения и переключает режим отображения команд на экране.')
+            print('ENDLOCAL       Завершает локализацию изменений среды для пакетного файла.')
+            print('ERASE          Удаляет один или несколько файлов.')
+            print('EXIT           Завершает работу программы CMD.EXE (интерпретатора командных строк).')
+            print('FC             Сравнивает два файла или два набора файлов и')
+            print('               отображает различия между ними.')
+            print('FIND           Ищет текстовую строку в одном или нескольких файлах.')
+            print('FINDSTR        Ищет строки в файлах.')
+            print('FOR            Запускает указанную команду для каждого из файлов в наборе.')
+            print('FORMAT         Форматирует диск для работы с Windows.')
+            print('FSUTIL         Отображает или настраивает свойства файловой системы.')
+            print('FTYPE          Отображает либо изменяет типы файлов, используемые при')
+            print('               сопоставлении по расширениям имен файлов.')
+            print('GOTO           Направляет интерпретатор команд Windows в отмеченную строку')
+            print('               пакетной программы.')
+            print('GPRESULT       Отображает информацию о групповой политике для компьютера или пользователя.')
+            print('GRAFTABL       Позволяет Windows отображать расширенный набор символов в')
+            print('               графическом режиме.')
+            print('HELP           Выводит справочную информацию о командах Windows.')
+            print('ICACLS         Отображает, изменяет, архивирует или восстанавливает')
+            print('               списки ACL для файлов и каталогов.')
+            print('IF             Выполняет условную обработку в пакетных программах.')
+            print('LABEL          Создает, изменяет или удаляет метки тома для дисков.')
+            print('MD             Создает каталог.')
+            print('MKDIR          Создает каталог.')
+            print('MKLINK         Создает символьные ссылки и жесткие связи')
+            print('MODE           Настраивает системные устройства.')
+            print('MORE           Последовательно отображает данные по частям размером в один экран.')
+            print('MOVE           Перемещает один или несколько файлов из одного каталога')
+            print('               в другой.')
+            print('OPENFILES      Отображает файлы, открытые для файлового ресурса удаленными пользователями.')
+            print('PATH           Отображает или устанавливает путь поиска исполняемых файлов.')
+            print('PAUSE          Приостанавливает выполнение пакетного файла и выводит сообщение.')
+            print('POPD           Восстанавливает предыдущее значение текущего каталога,')
+            print('               сохраненное с помощью команды PUSHD.')
+            print('PRINT          Выводит на печать содержимое текстового файла.')
+            print('PROMPT         Изменяет командную строку Windows.')
+            print('PUSHD          Сохраняет текущий каталог, затем изменяет его.')
+            print('RD             Удаляет каталог.')
+            print('RECOVER        Восстанавливает данные, которые можно прочитать, с плохого или поврежденного диска.')
+            print('REM            Записывает комментарии в пакетные файлы или файл CONFIG.SYS.')
+            print('REN            Переименовывает файлы.')
+            print('RENAME         Переименовывает файлы.')
+            print('REPLACE        Заменяет файлы.')
+            print('RMDIR          Удаляет каталог.')
+            print('ROBOCOPY       Улучшенная служебная программа копирования файлов и деревьев папок')
+            print('SET            Показывает, устанавливает или удаляет переменные среды Windows.')
+            print('SETLOCAL       Начинает локализацию изменений среды в пакетном файле.')
+            print('SC             Отображает или настраивает службы (фоновые процессы).')
+            print('SCHTASKS       Выполняет команды и запускает программы на компьютере по расписанию.')
+            print('SHIFT          Изменяет положение заменяемых параметров в пакетных файлах.')
+            print('SHUTDOWN       Позволяет локально или удаленно завершить работу компьютера.')
+            print('SORT           Сортирует ввод.')
+            print('START          Выполняет указанную программу или команду в отдельном окне.')
+            print('SUBST          Связывает путь с именем диска.')
+            print('SYSTEMINFO     Отображает сведения о свойствах и конфигурации определенного компьютера.')
+            print('TASKLIST       Отображает все выполняемые задачи, включая службы.')
+            print('TASKKILL       Прекращение или остановка процесса либо приложения.')
+            print('TIME           Отображает или устанавливает системное время.')
+            print('TITLE          Назначает заголовок окна для сеанса CMD.EXE.')
+            print('TREE           Графически отображает структуру каталогов диска или')
+            print('          пути.')
+            print('TYPE           Отображает содержимое текстовых файлов.')
+            print('VER            Отображает сведения о версии Windows.')
+            print('VERIFY         Устанавливает режим проверки в Windows правильности записи')
+            print('               файлов на диск.')
+            print('VOL            Отображает метку и серийный номер тома для диска.')
+            print('XCOPY          Копирует файлы и деревья папок.')
+            print('WMIC           Отображает сведения об инструментарии WMI в интерактивной командной оболочке.')
+    def start_command():
+        a = input('       ')
+        if a == 'start':
+            import os
+            a = input('       ')
+            os.system(a)
+    def cmd():
+        import os
+        a = input('       ')
+        if a == "start":
+            os.startfile('cmd')
\ No newline at end of file
